==> office-ui-fabric-react-0.34.0.tgz: package/lib-amd/demo/pages/PanelPage/examples/Panel.SmallRight.Example.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../../../index'], function (require, exports, React, index_1) {
    "use strict";
    var PanelSmallRightExample = (function (_super) {
        __extends(PanelSmallRightExample, _super);
        function PanelSmallRightExample() {
            _super.call(this);
            this.state = {
                showPanel: false
            };
        }
        PanelSmallRightExample.prototype.render = function () {
            return (React.createElement("div", null, React.createElement(index_1.Button, {description: 'Opens the Sample Panel', onClick: this._showPanel.bind(this)}, "Open Panel"), React.createElement(index_1.Panel, {isOpen: this.state.showPanel, type: index_1.PanelType.smallFixedFar, onDismiss: this._closePanel.bind(this), headerText: 'Panel - Small, right-aligned, fixed'}, React.createElement("span", {className: 'ms-font-m'}, "Content goes here."))));
        };
        PanelSmallRightExample.prototype._showPanel = function () {
            this.setState({ showPanel: true });
        };
        PanelSmallRightExample.prototype._closePanel = function () {
            this.setState({ showPanel: false });
        };
        return PanelSmallRightExample;
    }(React.Component));
    exports.PanelSmallRightExample = PanelSmallRightExample;
});

==> office-ui-fabric-react-0.66.0.tgz: package/lib-amd/demo/pages/PanelPage/examples/Panel.SmallRight.Example.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../../../index'], function (require, exports, React, index_1) {
    "use strict";
    var PanelSmallRightExample = (function (_super) {
        __extends(PanelSmallRightExample, _super);
        function PanelSmallRightExample() {
            _super.call(this);
            this.state = {
                showPanel: false
            };
        }
        PanelSmallRightExample.prototype.render = function () {
            return (React.createElement("div", null, 
                React.createElement(index_1.Button, {description: 'Opens the Sample Panel', onClick: this._showPanel.bind(this)}, "Open Panel"), 
                React.createElement(index_1.Panel, {isOpen: this.state.showPanel, type: index_1.PanelType.smallFixedFar, onDismiss: this._closePanel.bind(this), headerText: 'Panel - Small, right-aligned, fixed'}, 
                    React.createElement("span", {className: 'ms-font-m'}, "Content goes here.")
                )));
        };
        PanelSmallRightExample.prototype._showPanel = function () {
            this.setState({ showPanel: true });
        };
        PanelSmallRightExample.prototype._closePanel = function () {
            this.setState({ showPanel: false });
        };
        return PanelSmallRightExample;
    }(React.Component));
    exports.PanelSmallRightExample = PanelSmallRightExample;
});
